@@ -1,6 +1,6 @@
 package Spp;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use Exporter;
 our @ISA       = qw(Exporter);
@@ -45,6 +45,7 @@ sub get_grammar_ast {
   my $text = shift;
   my $parser = get_spp_parser();
   my $match = match($parser, $text);
+  # say to_json($match);
   return opt_spp_ast($match);
 }
 
@@ -118,10 +119,12 @@ sub lint {
 }
 
 sub parse {
-   my ($grammar_text, $code_text) = @_;
+   my ($grammar_text, $code_text, $mode) = @_;
    my $parser = get_parser($grammar_text);
+   # exit();
    lint_parser($parser);
-   return match($parser, $code_text);
+   # say to_json($parser); exit();
+   return match($parser, $code_text, $mode);
 }
 
 # --action spp --grammar grammar.file --target target.file
