@@ -3,7 +3,7 @@ package Spp::IsAtom;
 use Exporter;
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(
-  is_atom is_atom_name is_false is_true is_bool
+  is_atom is_atom_name is_false is_match is_true is_bool
   is_sym is_token is_rept is_look
   is_tillnot is_str is_expr);
 
@@ -24,6 +24,11 @@ sub is_false {
    return is_atom_name($atom, 'false');
 }
 
+sub is_match {
+   my $atom = shift;
+   return not(is_false($atom));
+}
+
 sub is_true {
    my $atom = shift;
    return is_atom_name($atom, 'true');
