@@ -30,7 +30,7 @@ sub lint_parser {
          say("warn! rule: <$name> not used");
       }
    }
-   say("Finish Lint $door grammar!");
+   # say("Finish Lint $door grammar!");
 }
 
 sub check_token {
