@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(opt_spp_ast);
 
 use 5.012;
 no warnings "experimental";
-use Spp::Tools qw(len tail rest first is_perl_str);
+use Spp::Tools qw(len tail rest first is_perl_str to_json);
 use Spp::IsChar qw(is_upper is_lower);
 use Spp::IsAtom qw(is_atom is_sym is_token is_rept is_look is_tillnot);
 
@@ -26,6 +26,7 @@ sub opt_spp_ast {
       }
    }
    for my $atom (@{$ast}) {
+      # say to_json($atom);
       my ($name, $spec) = @{$atom};
       if ($name eq 'Spec') {
          push @{$atoms}, opt_spp_spec($spec);
