@@ -4,8 +4,8 @@ use Exporter;
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(all is_perl_str is_perl_array
    read_file write_file str to_json from_json
-   count start_with end_with 
-   first tail rest trim len subarray);
+   count start_with end_with first tail rest
+   trim len subarray pos_info);
 
 use 5.012;
 no warnings "experimental";
@@ -129,4 +129,13 @@ sub subarray {
   die "subarray only could process array";
 }
 
+sub pos_info {
+   my ($ns, $info) = @_;
+   my $str = $ns->{code};
+   my $pos = $ns->{pos};
+   my ($line, $off, $len) = @{$pos};
+   my $str = substr($str, $off, $len);
+   return "! line: $line : $info |$str|";
+}
+
 1;
